@@ -7,7 +7,7 @@ use std::{io, process};
 
 use console::{set_colors_enabled, style, Key, Term};
 use insta::_cargo_insta_support::{
-    get_cargo, is_ci, SnapshotPrinter, SnapshotUpdate, TestRunner, ToolConfig,
+    get_cargo, get_pending_dir, is_ci, SnapshotPrinter, SnapshotUpdate, TestRunner, ToolConfig,
     UnreferencedSnapshots,
 };
 use insta::{internals::SnapshotContents, Snapshot};
@@ -66,7 +66,7 @@ impl fmt::Display for ColorWhen {
 enum Command {
     /// Interactively review snapshots
     #[command(alias = "verify")]
-    Review(ProcessCommand),
+    Review(ReviewCommand),
     /// Rejects all snapshots
     Reject(ProcessCommand),
     /// Accept all snapshots
@@ -119,6 +119,15 @@ struct ProcessCommand {
     quiet: bool,
 }
 
+#[derive(Args, Debug)]
+struct ReviewCommand {
+    #[command(flatten)]
+    process: ProcessCommand,
+    /// External diff tool to use (e.g., "delta --side-by-side").
+    #[arg(long, env = "INSTA_DIFF_TOOL")]
+    diff_tool: Option<String>,
+}
+
 #[derive(Args, Debug)]
 #[command(rename_all = "kebab-case", next_help_heading = "Test Runner Options")]
 struct TestRunnerOptions {
@@ -546,6 +555,33 @@ fn handle_target_args<'a>(
     })
 }
 
+/// Tries to strip a prefix from a path, with optional normalization fallback.
+///
+/// First attempts direct `strip_prefix` (preserves symlinks, works for Bazel).
+/// If that fails, tries normalizing both paths with `canonicalize()` and
+/// retrying (handles Windows path format differences like `\\?\` prefix).
+fn strip_prefix_with_fallback(path: &Path, prefix: &Path) -> Option<PathBuf> {
+    // Try direct strip_prefix first. This preserves symlinks which is
+    // essential for Bazel's execroot setup where paths are symlinks.
+    if let Ok(relative) = path.strip_prefix(prefix) {
+        return Some(relative.to_path_buf());
+    }
+
+    // Fallback: normalize both paths with canonicalize() and try again.
+    // This handles Windows path format differences (e.g., `\\?\` prefix,
+    // 8.3 short names). On Unix, canonicalize() follows symlinks, so we
+    // only reach here if direct strip failed (likely not a symlink case).
+    if let (Ok(normalized_path), Ok(normalized_prefix)) =
+        (path.canonicalize(), prefix.canonicalize())
+    {
+        if let Ok(relative) = normalized_path.strip_prefix(&normalized_prefix) {
+            return Some(relative.to_path_buf());
+        }
+    }
+
+    None
+}
+
 #[allow(clippy::type_complexity)]
 fn load_snapshot_containers<'a>(
     loc: &'a LocationInfo,
@@ -555,10 +591,34 @@ fn load_snapshot_containers<'a>(
 
     debug_assert!(!loc.packages.is_empty());
 
+    // Pending snapshots are stored with the same relative directory structure as the
+    // workspace. When INSTA_PENDING_DIR is set (e.g., for Bazel's hermetic builds),
+    // pending files go to that directory. Otherwise, they live next to their targets.
+    //
+    // The path mapping is: pending_root/relative/path → target_root/relative/path
+    // When pending_root == target_root, this is a no-op (just strip ".new").
+    let pending_dir = get_pending_dir();
+
     for package in &loc.packages {
         for root in find_snapshot_roots(package) {
-            roots.insert(root.clone());
-            for snapshot_container in find_pending_snapshots(&root, &loc.exts, loc.find_flags) {
+            let (search_root, target_root) = if let Some(ref pending) = pending_dir {
+                // Hermetic mode: map package root to pending_dir.
+                // Try direct strip first (for Bazel), fall back to normalized (for Windows).
+                match strip_prefix_with_fallback(&root, &loc.workspace_root) {
+                    Some(relative) => (pending.join(relative), root),
+                    // External test paths can't be mapped to pending_dir (they would
+                    // escape). We reject these at write time, so skip them here.
+                    None => continue,
+                }
+            } else {
+                // Default mode: search and target are the same
+                (root.clone(), root)
+            };
+
+            roots.insert(search_root.clone());
+            for snapshot_container in
+                find_pending_snapshots(&search_root, &target_root, &loc.exts, loc.find_flags)
+            {
                 snapshot_containers.push((snapshot_container?, package));
             }
         }
@@ -875,6 +935,12 @@ fn test_run(mut cmd: TestCommand, color: ColorWhen) -> Result<(), Box<dyn Error>
     let (mut proc, snapshot_ref_file, prevents_doc_run) =
         prepare_test_runner(&cmd, test_runner, color, &[], None, &loc)?;
 
+    // Set up warnings file for collecting warnings from test processes.
+    // This is necessary because test runners like nextest suppress stdout/stderr
+    // from passing tests by default.
+    let warnings_file = env::temp_dir().join(format!("insta-warnings-{}", Uuid::new_v4()));
+    proc.env("INSTA_WARNINGS_FILE", &warnings_file);
+
     if let Some(workspace_root) = &cmd.target_args.workspace_root {
         proc.current_dir(workspace_root);
     }
@@ -889,9 +955,11 @@ fn test_run(mut cmd: TestCommand, color: ColorWhen) -> Result<(), Box<dyn Error>
     // Note that unlike `cargo test`, `cargo test --doctest` will run doctests
     // even on crates that specify `doctests = false`. But I don't think there's
     // a way to replicate the `cargo test` behavior.
+    let disable_nextest_doctest =
+        cmd.disable_nextest_doctest || loc.tool_config.disable_nextest_doctest();
     if matches!(cmd.test_runner, TestRunner::Nextest)
         && !prevents_doc_run
-        && !cmd.disable_nextest_doctest
+        && !disable_nextest_doctest
     {
         // Check if there are doctests and show warning
         if has_doctests(&loc.packages) {
@@ -910,9 +978,24 @@ fn test_run(mut cmd: TestCommand, color: ColorWhen) -> Result<(), Box<dyn Error>
             snapshot_ref_file.as_deref(),
             &loc,
         )?;
+        // Use the same warnings file for doctests
+        proc.env("INSTA_WARNINGS_FILE", &warnings_file);
         success = success && proc.status()?.success();
     }
 
+    // Display any warnings collected during tests (deduplicated)
+    if warnings_file.exists() {
+        if let Ok(contents) = fs::read_to_string(&warnings_file) {
+            let mut seen = std::collections::BTreeSet::new();
+            for line in contents.lines().map(str::trim).filter(|l| !l.is_empty()) {
+                if seen.insert(line.to_owned()) {
+                    eprintln!("{}", line);
+                }
+            }
+        }
+        fs::remove_file(&warnings_file).ok();
+    }
+
     if !success && cmd.review {
         eprintln!(
             "{} non snapshot tests failed, skipping review",
@@ -973,7 +1056,32 @@ fn test_run(mut cmd: TestCommand, color: ColorWhen) -> Result<(), Box<dyn Error>
     }
 }
 
+/// Quick check if a file is likely an insta snapshot by checking for the
+/// `---\nsource:` prefix. This distinguishes insta snapshots from other
+/// snapshot formats (e.g., vitest, jest) that may use the same `.snap` extension.
+///
+/// Only reads 16 bytes for efficiency (longest pattern is 13 bytes for CRLF).
+fn is_likely_insta_snapshot(path: &Path) -> bool {
+    use io::Read;
+    let mut buf = [0u8; 16];
+    let Ok(mut file) = fs::File::open(path) else {
+        return false;
+    };
+    let Ok(n) = file.read(&mut buf) else {
+        return false;
+    };
+    let s = &buf[..n];
+    s.starts_with(b"---\nsource:") || s.starts_with(b"---\r\nsource:")
+}
+
 /// Scan for any snapshots that were not referenced by any test.
+///
+/// TODO: Support unreferenced snapshot cleanup in hermetic/Bazel workflows.
+/// Currently this only works when tests can directly access the source tree.
+/// In Bazel's sandbox, tests can't delete source files. A potential solution:
+/// write `.snap.unreferenced` marker files to `INSTA_PENDING_DIR` during tests,
+/// then process them during `cargo insta review` (which runs outside the sandbox).
+/// See: <https://github.com/mitsuhiko/insta/pull/852#issuecomment-2728955522>
 fn handle_unreferenced_snapshots(
     snapshot_ref_path: &Path,
     loc: &LocationInfo<'_>,
@@ -1040,7 +1148,9 @@ fn handle_unreferenced_snapshots(
             path.extension()
                 .map(|x| x != "new" && x != "pending-snap")
                 .unwrap_or(true)
-        });
+        })
+        // skip files that don't look like insta snapshots (e.g., vitest .snap files)
+        .filter(|path| is_likely_insta_snapshot(path));
 
         for path in unreferenced_snapshots {
             if !encountered_any {
@@ -1190,6 +1300,11 @@ fn prepare_test_runner<'snapshot_ref>(
         proc.env("INSTA_FORCE_PASS", "1");
     }
 
+    // Pass INSTA_PENDING_DIR to the test subprocess if set
+    if let Some(pending_dir) = get_pending_dir() {
+        proc.env("INSTA_PENDING_DIR", pending_dir);
+    }
+
     proc.env(
         "INSTA_UPDATE",
         // Don't set `INSTA_UPDATE=force` for `--force-update-snapshots` on
@@ -1476,19 +1591,27 @@ pub(crate) fn run() -> Result<(), Box<dyn Error>> {
 
     handle_color(opts.color);
     match opts.command {
-        Command::Review(ref cmd) | Command::Accept(ref cmd) | Command::Reject(ref cmd) => {
+        Command::Review(ref cmd) => {
+            if let Some(ref diff_tool) = cmd.diff_tool {
+                env::set_var("INSTA_DIFF_TOOL", diff_tool);
+            }
             review_snapshots(
-                cmd.quiet,
-                cmd.snapshot_filter.as_deref(),
-                &handle_target_args(&cmd.target_args, &[])?,
-                match opts.command {
-                    Command::Review(_) => None,
-                    Command::Accept(_) => Some(Operation::Accept),
-                    Command::Reject(_) => Some(Operation::Reject),
-                    _ => unreachable!(),
-                },
+                cmd.process.quiet,
+                cmd.process.snapshot_filter.as_deref(),
+                &handle_target_args(&cmd.process.target_args, &[])?,
+                None,
             )
         }
+        Command::Accept(ref cmd) | Command::Reject(ref cmd) => review_snapshots(
+            cmd.quiet,
+            cmd.snapshot_filter.as_deref(),
+            &handle_target_args(&cmd.target_args, &[])?,
+            match opts.command {
+                Command::Accept(_) => Some(Operation::Accept),
+                Command::Reject(_) => Some(Operation::Reject),
+                _ => unreachable!(),
+            },
+        ),
         Command::Test(cmd) => test_run(cmd, opts.color.unwrap_or(ColorWhen::Auto)),
         Command::Show(cmd) => show_cmd(cmd),
         Command::PendingSnapshots(cmd) => pending_snapshots_cmd(cmd),
